@@ -24,6 +24,7 @@ class pysubsonic:
         full_url = f"{self.url}/rest/{endpoint}?{self.make_bad_auth_params()}&c={self.client}&v={self.ver}"
         if extra != "":
             full_url += "&" + extra
+        print("Making request: " + full_url)
         r = requests.get(full_url)
         return r.text
     def do_search3(self, query):
@@ -47,6 +48,9 @@ class pysubsonic:
             for sid in songid:
                 params += f"&songID={sid}"
         return self.do_request("createPlaylist", params)
+    def update_playlist(self, playlistId, songIdToAdd):
+        params = f"playlistId={playlistId}&songIdToAdd={songIdToAdd"
+        return self.do_request("updatePlaylist", params)
     def parse_playlist_id(self, response_data):
         soup = BeautifulSoup(response_data, 'xml')
         pl = soup.find_all('playlist')[0]
